@@ -4,7 +4,7 @@ CREATE TABLE IF NOT EXISTS schema_version (
 
 DELETE FROM schema_version;
 
-INSERT INTO schema_version (version) VALUES (17);
+INSERT INTO schema_version (version) VALUES (18);
 
 CREATE TABLE IF NOT EXISTS directories (
   path TEXT NOT NULL,
@@ -91,7 +91,10 @@ CREATE TABLE IF NOT EXISTS songs (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
@@ -169,7 +172,10 @@ CREATE TABLE IF NOT EXISTS subsonic_songs (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
@@ -247,7 +253,10 @@ CREATE TABLE IF NOT EXISTS tidal_artists_songs (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
@@ -325,7 +334,10 @@ CREATE TABLE IF NOT EXISTS tidal_albums_songs (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
@@ -403,7 +415,10 @@ CREATE TABLE IF NOT EXISTS tidal_songs (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
@@ -481,7 +496,10 @@ CREATE TABLE IF NOT EXISTS qobuz_artists_songs (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
@@ -559,7 +577,10 @@ CREATE TABLE IF NOT EXISTS qobuz_albums_songs (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
@@ -637,7 +658,10 @@ CREATE TABLE IF NOT EXISTS qobuz_songs (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
@@ -735,7 +759,10 @@ CREATE TABLE IF NOT EXISTS playlist_items (
   musicbrainz_track_id TEXT,
   musicbrainz_disc_id TEXT,
   musicbrainz_release_group_id TEXT,
-  musicbrainz_work_id TEXT
+  musicbrainz_work_id TEXT,
+
+  ebur128_integrated_loudness_lufs REAL,
+  ebur128_loudness_range_lu REAL
 
 );
 
