@@ -19,10 +19,11 @@
 
 #include <QString>
 
+#include "core/shared_ptr.h"
 #include "core/taskmanager.h"
 #include "collectiontask.h"
 
-CollectionTask::CollectionTask(TaskManager *task_manager, const QString &message) : task_manager_(task_manager), task_id_(-1) {
+CollectionTask::CollectionTask(SharedPtr<TaskManager> task_manager, const QString &message) : task_manager_(task_manager), task_id_(-1) {
 
   if (task_manager_) task_id_ = task_manager_->StartTask(message);
 
