@@ -71,6 +71,8 @@
 #include "organize/organizeerrordialog.h"
 #include "settings/collectionsettingspage.h"
 
+using std::make_unique;
+
 CollectionView::CollectionView(QWidget *parent)
     : AutoExpandingTreeView(parent),
       app_(nullptr),
@@ -402,7 +404,6 @@ void CollectionView::contextMenuEvent(QContextMenuEvent *e) {
   }
 
   const int songs_selected = regular_elements;
-  const bool regular_elements_only = songs_selected == regular_elements && regular_elements > 0;
 
   // in all modes
   action_load_->setEnabled(songs_selected > 0);
@@ -430,8 +431,8 @@ void CollectionView::contextMenuEvent(QContextMenuEvent *e) {
   action_delete_files_->setVisible(false);
 #endif
 
-  action_show_in_various_->setVisible(regular_elements_only);
-  action_no_show_in_various_->setVisible(regular_elements_only);
+  action_show_in_various_->setVisible(songs_selected > 0);
+  action_no_show_in_various_->setVisible(songs_selected > 0);
 
   // only when all selected items are editable
   action_organize_->setEnabled(regular_elements == regular_editable);
@@ -573,7 +574,7 @@ SongList CollectionView::GetSelectedSongs() const {
 void CollectionView::Organize() {
 
   if (!organize_dialog_) {
-    organize_dialog_ = std::make_unique<OrganizeDialog>(app_->task_manager(), app_->collection_backend(), this);
+    organize_dialog_ = make_unique<OrganizeDialog>(app_->task_manager(), app_->collection_backend(), this);
   }
 
   organize_dialog_->SetDestinationModel(app_->collection_model()->directory_model());
@@ -591,8 +592,8 @@ void CollectionView::Organize() {
 void CollectionView::EditTracks() {
 
   if (!edit_tag_dialog_) {
-    edit_tag_dialog_ = std::make_unique<EditTagDialog>(app_, this);
-    QObject::connect(edit_tag_dialog_.get(), &EditTagDialog::Error, this, &CollectionView::EditTagError);
+    edit_tag_dialog_ = make_unique<EditTagDialog>(app_, this);
+    QObject::connect(&*edit_tag_dialog_, &EditTagDialog::Error, this, &CollectionView::EditTagError);
   }
   const SongList songs = GetSelectedSongs();
   edit_tag_dialog_->SetSongs(songs);
@@ -614,7 +615,7 @@ void CollectionView::CopyToDevice() {
 
 #ifndef Q_OS_WIN
   if (!organize_dialog_) {
-    organize_dialog_ = std::make_unique<OrganizeDialog>(app_->task_manager(), nullptr, this);
+    organize_dialog_ = make_unique<OrganizeDialog>(app_->task_manager(), nullptr, this);
   }
 
   organize_dialog_->SetDestinationModel(app_->device_manager()->connected_devices_model(), true);
@@ -686,7 +687,7 @@ void CollectionView::Delete() {
   if (DeleteConfirmationDialog::warning(files) != QDialogButtonBox::Yes) return;
 
   // We can cheat and always take the storage of the first directory, since they'll all be FilesystemMusicStorage in a collection and deleting doesn't check the actual directory.
-  std::shared_ptr<MusicStorage> storage = app_->collection_model()->directory_model()->index(0, 0).data(MusicStorage::Role_Storage).value<std::shared_ptr<MusicStorage>>();
+  SharedPtr<MusicStorage> storage = app_->collection_model()->directory_model()->index(0, 0).data(MusicStorage::Role_Storage).value<SharedPtr<MusicStorage>>();
 
   DeleteFiles *delete_files = new DeleteFiles(app_->task_manager(), storage, true);
   QObject::connect(delete_files, &DeleteFiles::Finished, this, &CollectionView::DeleteFilesFinished);
