@@ -24,12 +24,11 @@
 
 #include "config.h"
 
-#include <memory>
-
 #include <QDialog>
 #include <QObject>
 #include <QString>
 
+#include "core/scoped_ptr.h"
 #include "collectionmodel.h"
 #include "ui_groupbydialog.h"
 
@@ -55,8 +54,8 @@ class GroupByDialog : public QDialog {
   void Reset();
 
  private:
-  std::unique_ptr<Ui_GroupByDialog> ui_;
-  std::unique_ptr<GroupByDialogPrivate> p_;
+  ScopedPtr<Ui_GroupByDialog> ui_;
+  ScopedPtr<GroupByDialogPrivate> p_;
 };
 
 #endif  // GROUPBYDIALOG_H
