@@ -28,6 +28,7 @@
 #include <QUrl>
 #include <QMetaObject>
 
+#include "shared_ptr.h"
 #include "taskmanager.h"
 #include "song.h"
 #include "deletefiles.h"
@@ -35,7 +36,7 @@
 
 const int DeleteFiles::kBatchSize = 50;
 
-DeleteFiles::DeleteFiles(TaskManager *task_manager, std::shared_ptr<MusicStorage> storage, const bool use_trash, QObject *parent)
+DeleteFiles::DeleteFiles(SharedPtr<TaskManager> task_manager, SharedPtr<MusicStorage> storage, const bool use_trash, QObject *parent)
     : QObject(parent),
       thread_(nullptr),
       task_manager_(task_manager),
