@@ -952,7 +952,7 @@ QString Song::TextForFiletype(const FileType filetype) {
     case FileType::OggVorbis:   return "Ogg Vorbis";
     case FileType::OggOpus:     return "Ogg Opus";
     case FileType::OggSpeex:    return "Ogg Speex";
-    case FileType::MPEG:        return "MP3";
+    case FileType::MPEG:        return "MPEG";
     case FileType::MP4:         return "MP4 AAC";
     case FileType::ASF:         return "Windows Media audio";
     case FileType::AIFF:        return "AIFF";
@@ -1095,6 +1095,7 @@ Song::FileType Song::FiletypeByDescription(const QString &text) {
   else if (text.compare("Vorbis", Qt::CaseInsensitive) == 0) return FileType::OggVorbis;
   else if (text.compare("Opus", Qt::CaseInsensitive) == 0) return FileType::OggOpus;
   else if (text.compare("Speex", Qt::CaseInsensitive) == 0) return FileType::OggSpeex;
+  else if (text.compare("MPEG-1 Layer 2 (MP2)", Qt::CaseInsensitive) == 0) return FileType::MPEG;
   else if (text.compare("MPEG-1 Layer 3 (MP3)", Qt::CaseInsensitive) == 0) return FileType::MPEG;
   else if (text.compare("MPEG-4 AAC", Qt::CaseInsensitive) == 0) return FileType::MP4;
   else if (text.compare("WMA", Qt::CaseInsensitive) == 0) return FileType::ASF;
@@ -1120,6 +1121,7 @@ Song::FileType Song::FiletypeByExtension(const QString &ext) {
   else if (ext.compare("ogg", Qt::CaseInsensitive) == 0 || ext.compare("oga", Qt::CaseInsensitive) == 0) return FileType::OggVorbis;
   else if (ext.compare("opus", Qt::CaseInsensitive) == 0) return FileType::OggOpus;
   else if (ext.compare("speex", Qt::CaseInsensitive) == 0 || ext.compare("spx", Qt::CaseInsensitive) == 0) return FileType::OggSpeex;
+  else if (ext.compare("mp2", Qt::CaseInsensitive) == 0) return FileType::MPEG;
   else if (ext.compare("mp3", Qt::CaseInsensitive) == 0) return FileType::MPEG;
   else if (ext.compare("mp4", Qt::CaseInsensitive) == 0 || ext.compare("m4a", Qt::CaseInsensitive) == 0 || ext.compare("aac", Qt::CaseInsensitive) == 0) return FileType::MP4;
   else if (ext.compare("asf", Qt::CaseInsensitive) == 0 || ext.compare("wma", Qt::CaseInsensitive) == 0) return FileType::ASF;
