@@ -1,6 +1,6 @@
 /*
  * Strawberry Music Player
- * Copyright 2019, Jonas Kvinge <jonas@jkvinge.net>
+ * Copyright 2019-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@
 #include "translations.h"
 #include "core/potranslator.h"
 
-Translations::Translations() {}
+Translations::Translations(QObject *parent) : QObject(parent) {}
 Translations::~Translations() {
 
   for (QTranslator *t : translations_) {
