@@ -28,6 +28,7 @@
 #include <QTimer>
 #include <QString>
 
+#include "core/shared_ptr.h"
 #include "core/networkaccessmanager.h"
 #include "core/song.h"
 #include "albumcoverfetcher.h"
@@ -37,7 +38,7 @@ using namespace std::chrono_literals;
 
 const int AlbumCoverFetcher::kMaxConcurrentRequests = 5;
 
-AlbumCoverFetcher::AlbumCoverFetcher(CoverProviders *cover_providers, NetworkAccessManager *network, QObject *parent)
+AlbumCoverFetcher::AlbumCoverFetcher(SharedPtr<CoverProviders> cover_providers, SharedPtr<NetworkAccessManager> network, QObject *parent)
     : QObject(parent),
       cover_providers_(cover_providers),
       network_(network),
