@@ -32,7 +32,6 @@
 #include <QString>
 #include <QAtomicInt>
 
-class NetworkAccessManager;
 class CoverProvider;
 
 // This is a repository for cover providers.
@@ -60,8 +59,6 @@ class CoverProviders : public QObject {
 
   int NextId();
 
-  NetworkAccessManager *network() const { return network_; }
-
  private slots:
   void ProviderDestroyed();
 
@@ -70,8 +67,6 @@ class CoverProviders : public QObject {
 
   static int NextOrderId;
 
-  NetworkAccessManager *network_;
-
   QMap<CoverProvider*, QString> cover_providers_;
   QMutex mutex_;
 
