@@ -40,7 +40,7 @@ class DeezerCoverProvider : public JsonCoverProvider {
   Q_OBJECT
 
  public:
-  explicit DeezerCoverProvider(Application *app, NetworkAccessManager *network, QObject *parent = nullptr);
+  explicit DeezerCoverProvider(Application *app, SharedPtr<NetworkAccessManager> network, QObject *parent = nullptr);
   ~DeezerCoverProvider() override;
 
   bool StartSearch(const QString &artist, const QString &album, const QString &title, const int id) override;
@@ -59,7 +59,6 @@ class DeezerCoverProvider : public JsonCoverProvider {
   static const int kLimit;
 
   QList<QNetworkReply*> replies_;
-
 };
 
 #endif  // DEEZERCOVERPROVIDER_H
