@@ -2,6 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
+ * Copyright 2018-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,17 +42,17 @@ class DeviceStateFilterModel : public QSortFilterProxyModel {
   void setSourceModel(QAbstractItemModel *sourceModel) override;
 
  signals:
-  void IsEmptyChanged(bool is_empty);
+  void IsEmptyChanged(const bool is_empty);
 
  protected:
   bool filterAcceptsRow(int row, const QModelIndex &parent) const override;
 
  private slots:
   void ProxyReset();
-  void ProxyRowCountChanged(QModelIndex idx, int first, int last);
+  void ProxyRowCountChanged(const QModelIndex &idx, const int first, const int last);
 
  private:
   DeviceManager::State state_;
 };
 
-#endif // DEVICESTATEFILTERMODEL_H
+#endif  // DEVICESTATEFILTERMODEL_H
