@@ -2,6 +2,7 @@
  * Strawberry Music Player
  * This file was part of Clementine.
  * Copyright 2010, David Sansome <me@davidsansome.com>
+ * Copyright 2019-2021, Jonas Kvinge <jonas@jkvinge.net>
  *
  * Strawberry is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,8 +35,9 @@ class Application;
 
 class Console : public QDialog {
   Q_OBJECT
+
  public:
-  Console(Application *app, QWidget *parent = nullptr);
+  explicit Console(Application *app, QWidget *parent = nullptr);
 
  private slots:
   void RunQuery();
