@@ -29,7 +29,7 @@
 #include <QString>
 #include <QStringList>
 
-class QHideEvent;
+class QCloseEvent;
 class Ui_ErrorDialog;
 
 class ErrorDialog : public QDialog {
@@ -43,7 +43,7 @@ class ErrorDialog : public QDialog {
   void ShowMessage(const QString &message);
 
  protected:
-  void hideEvent(QHideEvent*) override;
+  void closeEvent(QCloseEvent *e) override;
 
  private:
   void UpdateContent();
