@@ -21,19 +21,18 @@
 
 #include <alsa/asoundlib.h>
 
-#include <QList>
 #include <QString>
 
 #include <core/logging.h>
 
-#include "devicefinder.h"
 #include "alsapcmdevicefinder.h"
+#include "enginedevice.h"
 
 AlsaPCMDeviceFinder::AlsaPCMDeviceFinder() : DeviceFinder("alsa", { "alsa", "alsasink" }) {}
 
-QList<DeviceFinder::Device> AlsaPCMDeviceFinder::ListDevices() {
+EngineDeviceList AlsaPCMDeviceFinder::ListDevices() {
 
-  QList<Device> ret;
+  EngineDeviceList ret;
 
   void **hints = nullptr;
   if (snd_device_name_hint(-1, "pcm", &hints) < 0) {
@@ -64,10 +63,10 @@ QList<DeviceFinder::Device> AlsaPCMDeviceFinder::ListDevices() {
         description.append(desc_last);
       }
 
-      Device device;
+      EngineDevice device;
       device.value = name;
       device.description = description;
-      device.iconname = GuessIconName(device.description);
+      device.iconname = device.GuessIconName();
       ret << device;  // clazy:exclude=reserve-candidates
     }
     if (hint_io) free(hint_io);
