@@ -21,9 +21,9 @@
 
  #include "config.h"
 
-#include "globalshortcutsbackend-macos.h"
+ #include <QtGlobal>
 
-#include <boost/noncopyable.hpp>
+#include "globalshortcutsbackend-macos.h"
 
 #include <AppKit/NSEvent.h>
 #include <AppKit/NSWorkspace.h>
@@ -43,7 +43,7 @@
 
 #import "core/SBSystemPreferences.h"
 
-class GlobalShortcutsBackendMacOSPrivate : boost::noncopyable {
+class GlobalShortcutsBackendMacOSPrivate {
  public:
   explicit GlobalShortcutsBackendMacOSPrivate(GlobalShortcutsBackendMacOS *backend)
       : global_monitor_(nil), local_monitor_(nil), backend_(backend) {}
@@ -73,6 +73,8 @@ class GlobalShortcutsBackendMacOSPrivate : boost::noncopyable {
   id global_monitor_;
   id local_monitor_;
   GlobalShortcutsBackendMacOS *backend_;
+
+  Q_DISABLE_COPY(GlobalShortcutsBackendMacOSPrivate)
 };
 
 GlobalShortcutsBackendMacOS::GlobalShortcutsBackendMacOS(GlobalShortcutsManager *manager, QObject *parent)
