@@ -24,8 +24,6 @@
 
 #include "config.h"
 
-#include <memory>
-
 #include <QtGlobal>
 #include <QObject>
 #include <QWidget>
@@ -40,10 +38,11 @@
 #include <QPixmap>
 #include <QMetaType>
 
+#include "core/scoped_ptr.h"
+#include "core/shared_ptr.h"
 #include "core/song.h"
 #include "collection/collectionmodel.h"
 #include "covermanager/albumcoverloaderresult.h"
-#include "settings/settingsdialog.h"
 
 class QSortFilterProxyModel;
 class QMimeData;
@@ -82,7 +81,7 @@ class InternetSearchView : public QWidget {
   };
   using ResultList = QList<Result>;
 
-  void Init(Application *app, InternetService *service);
+  void Init(Application *app, SharedPtr<InternetService> service);
 
   bool SearchFieldHasFocus() const;
   void FocusSearchField();
@@ -184,9 +183,9 @@ class InternetSearchView : public QWidget {
 
  private:
   Application *app_;
-  InternetService *service_;
+  SharedPtr<InternetService> service_;
   Ui_InternetSearchView *ui_;
-  std::unique_ptr<GroupByDialog> group_by_dialog_;
+  ScopedPtr<GroupByDialog> group_by_dialog_;
 
   QMenu *context_menu_;
   QList<QAction*> context_actions_;
@@ -215,7 +214,6 @@ class InternetSearchView : public QWidget {
   QMap<int, PendingState> pending_searches_;
 
   QMap<quint64, QPair<QModelIndex, QString>> cover_loader_tasks_;
-
 };
 Q_DECLARE_METATYPE(InternetSearchView::Result)
 Q_DECLARE_METATYPE(InternetSearchView::ResultList)
