@@ -29,16 +29,16 @@
 #include <QString>
 #include <QRegularExpression>
 
+#include "core/shared_ptr.h"
+#include "core/networkaccessmanager.h"
 #include "lyricssearchrequest.h"
 #include "lyricssearchresult.h"
 
-class NetworkAccessManager;
-
 class LyricsProvider : public QObject {
   Q_OBJECT
 
  public:
-  explicit LyricsProvider(const QString &name, const bool enabled, const bool authentication_required, NetworkAccessManager *network, QObject *parent);
+  explicit LyricsProvider(const QString &name, const bool enabled, const bool authentication_required, SharedPtr<NetworkAccessManager> network, QObject *parent);
 
   QString name() const { return name_; }
   bool is_enabled() const { return enabled_; }
@@ -56,9 +56,6 @@ class LyricsProvider : public QObject {
 
   virtual void Error(const QString &error, const QVariant &debug = QVariant()) = 0;
 
- protected:
-  QString ParseLyricsFromHTML(const QString &content, const QRegularExpression &start_tag, const QRegularExpression &end_tag, const QRegularExpression &lyrics_start, const bool multiple);
-
  signals:
   void AuthenticationComplete(const bool success, const QStringList &errors = QStringList());
   void AuthenticationSuccess();
@@ -66,11 +63,11 @@ class LyricsProvider : public QObject {
   void SearchFinished(const int id, const LyricsSearchResults &results = LyricsSearchResults());
 
  protected:
-  NetworkAccessManager *network_;
-  QString name_;
+  SharedPtr<NetworkAccessManager> network_;
+  const QString name_;
   bool enabled_;
   int order_;
-  bool authentication_required_;
+  const bool authentication_required_;
 };
 
 #endif  // LYRICSPROVIDER_H
