@@ -29,6 +29,7 @@
 #include <QString>
 #include <QUrl>
 
+#include "core/shared_ptr.h"
 #include "core/song.h"
 
 class Player;
@@ -41,7 +42,7 @@ class SongLoaderInserter : public QObject {
   Q_OBJECT
 
  public:
-  explicit SongLoaderInserter(TaskManager *task_manager, CollectionBackendInterface *collection, const Player *player, QObject *parent = nullptr);
+  explicit SongLoaderInserter(SharedPtr<TaskManager> task_manager, SharedPtr<CollectionBackendInterface> collection_backend, const SharedPtr<Player> player, QObject *parent = nullptr);
   ~SongLoaderInserter() override;
 
   void Load(Playlist *destination, int row, bool play_now, bool enqueue, bool enqueue_next, const QList<QUrl> &urls);
@@ -62,7 +63,7 @@ class SongLoaderInserter : public QObject {
   void AsyncLoad();
 
  private:
-  TaskManager *task_manager_;
+  SharedPtr<TaskManager> task_manager_;
 
   Playlist *destination_;
   int row_;
@@ -73,8 +74,8 @@ class SongLoaderInserter : public QObject {
   SongList songs_;
 
   QList<SongLoader*> pending_;
-  CollectionBackendInterface *collection_;
-  const Player *player_;
+  SharedPtr<CollectionBackendInterface> collection_backend_;
+  const SharedPtr<Player> player_;
 };
 
 #endif  // SONGLOADERINSERTER_H
