@@ -25,7 +25,7 @@
 
 #include "core/tagreaderclient.h"
 #include "core/song.h"
-#include "collection/sqlrow.h"
+#include "core/sqlrow.h"
 #include "playlistitem.h"
 #include "songplaylistitem.h"
 
