@@ -21,13 +21,15 @@
 #ifndef ASXPARSER_H
 #define ASXPARSER_H
 
+#include "config.h"
+
 #include <QObject>
 #include <QByteArray>
 #include <QString>
 #include <QStringList>
 #include <QDir>
 
-#include "config.h"
+#include "core/shared_ptr.h"
 #include "core/song.h"
 #include "settings/playlistsettingspage.h"
 #include "xmlparser.h"
@@ -41,7 +43,7 @@ class ASXParser : public XMLParser {
   Q_OBJECT
 
  public:
-  explicit ASXParser(CollectionBackendInterface *collection, QObject *parent = nullptr);
+  explicit ASXParser(SharedPtr<CollectionBackendInterface> collection_backend, QObject *parent = nullptr);
 
   QString name() const override { return "ASX"; }
   QStringList file_extensions() const override { return QStringList() << "asx"; }
