@@ -29,6 +29,7 @@
 #include <QStringList>
 #include <QUrl>
 
+#include "core/shared_ptr.h"
 #include "core/song.h"
 #include "qobuzbaserequest.h"
 
@@ -40,7 +41,7 @@ class QobuzStreamURLRequest : public QobuzBaseRequest {
   Q_OBJECT
 
  public:
-  explicit QobuzStreamURLRequest(QobuzService *service, NetworkAccessManager *network, const QUrl &media_url, const uint id, QObject *parent = nullptr);
+  explicit QobuzStreamURLRequest(QobuzService *service, SharedPtr<NetworkAccessManager> network, const QUrl &media_url, const uint id, QObject *parent = nullptr);
   ~QobuzStreamURLRequest();
 
   void GetStreamURL();
@@ -74,7 +75,6 @@ class QobuzStreamURLRequest : public QobuzBaseRequest {
   int tries_;
   bool need_login_;
   QStringList errors_;
-
 };
 
 #endif  // QOBUZSTREAMURLREQUEST_H
